#
# spec file for package prometheus-sap_host_exporter
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           prometheus-sap_host_exporter
# Version will be processed via set_version source service
Version:        0.5.1+git.1593777035.a5d05f8
Release:        150200.4.5.1
Summary:        Prometheus exporter for SAP systems (a.k.a. NetWeaver)
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://github.com/SUSE/sap_host_exporter
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
ExclusiveArch:  aarch64 x86_64 ppc64le s390x
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  go >= 1.12
Provides:       sap_host_exporter = %{version}-%{release}
Provides:       prometheus(sap_host_exporter) = %{version}-%{release}
# Unlike C/C++ packages, Golang packages do not have header files. They are statically built so the main package is also the devel package.
Provides:       %{name}-devel = %{version}
Provides:       %{name}-devel-static = %{version}

# Make sure that the binary is not getting stripped.
%undefine _build_create_debug
%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%description
Prometheus exporter for Pacemaker HA clusters metrics

%prep
%setup -q            # unpack project sources
%setup -q -T -D -a 1 # unpack go dependencies in vendor.tar.gz, which was prepared by the source services

%define shortname sap_host_exporter

%build

export CGO_ENABLED=0
go build -mod=vendor \
         -ldflags="-s -w -X main.version=%{version}" \
         -o %{shortname}

%install

# Install the binary.
install -D -m 0755 %{shortname} "%{buildroot}%{_bindir}/%{shortname}"

# Install the systemd unit
install -D -m 0644 %{shortname}@.service %{buildroot}%{_unitdir}/%{name}@.service

# Install the default config
install -D -m 0600 doc/%{shortname}.yaml "%{buildroot}/etc/%{shortname}/default.yaml"

# Install compat wrapper for legacy init systems
install -Dd -m 0755 %{buildroot}%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}

%pre
%service_add_pre %{name}@.service

%post
%service_add_post %{name}@.service

%preun
%service_del_preun %{name}@.service

%postun
%service_del_postun %{name}@.service

%files
%defattr(-,root,root)
%doc *.md
%doc doc/*.md
%if 0%{?suse_version} >= 1500
%license LICENSE
%else
%doc LICENSE
%endif
%{_bindir}/%{shortname}
%{_unitdir}/%{name}@.service
%{_sbindir}/rc%{name}
%dir /etc/%{shortname}/
%config /etc/%{shortname}/default.yaml

%changelog
* Fri Jul  3 2020 UTC - shap-staff@suse.de
- Release 0.5.1
  [#]# Fixed
  - Make OBS RPM builds reproducible by removing the build date. (#48)
* Thu Jul  2 2020 UTC - shap-staff@suse.de
- Release 0.5.0
  [#]# Added
  - `--version` CLI flag (#42)
  - Grafana dashboard is now part of the repo, although packaged independently (#44)
  [#]# Changed
  - Bumped required Go version to 1.12 (#43)
  - Switched CI from Travis to GitHub Actions (#45)
  [#]# Fixed
  - Some usage details are now further clarified (#47)
* Wed May 20 2020 stefano.torresi@suse.com
- Backport to SLE12SP3 and SLE15. (jsc#SLE-10902, jsc#SLE-10903, jsc#ECO-817, jsc#ECO-818)
* Tue Apr 21 2020 UTC - shap-staff@suse.de
- Release 0.4.0
  [#]# Added
  - Unix Domain Socket can now be used in place of TCP/IP to connect to SAPControl (#32)
  - `sap_start_service_instances` metric now tracks the status of the current SAP Instance. (#38)
  - Collectors are now activated conditionally, only for SAP processes that are actually running. (#39)
  - Common labels to identify source SAP instance are now added to all metrics (#40)
  [#]# Changed
  - Updated CI with OBS to continuously deliver the master branch (#29)
  - Collector error handling is now more consistent across the board (#33)
  [#]# Fixed
  - Concurrent metric recording no longer leaks goroutines (#35)
  - Configuration sanitation is now applied correctly (#37)
  [#]# Removed
  - HA Checks and alert collector have been entirely removed due to SAP system crashes caused by the related SAPControl methods (#36 #41)
* Mon Mar 23 2020 UTC - shap-staff@suse.de
- Release 0.3.0
  [#]# Added
  - Alert metrics collector (#21)
  - `make obs-workdir` target can now handle custom Git branches and forks via environment variables (#25)
  [#]# Changed
  - Some metric now properly use the `Counter` type instead of `Gauge` and are more semantically correct. (#23)
  - `sap-control-url` setting now has a default value and doesn't require users to explicitly input the URL scheme. (#26)
  - `go_*` debug metrics are only shown when the log level is `debug` or higher. (#24)
  - Refactored configuration code (#26)
  [#]# Fixed
  - Enqueue Server metrics are now properly documented (#23)
  - Documentation can be fully browsed from the README ToC (#28)
* Thu Mar 19 2020 UTC - shap-staff@suse.de
- Release 0.2.3
  [#] Fixed:
  - Fix failure of enabling service in deployment (https://github.com/SUSE/sap_host_exporter/pull/20)
* Wed Mar 18 2020 UTC - shap-staff@suse.de
- Release 0.2.1
  [#] fixed:
  - fix rpm macro on obs/packaging(https://github.com/SUSE/sap_host_exporter/pull/18)
* Tue Mar 17 2020 UTC - shap-staff@suse.de
- Release 0.2.0
  [#]# Added
  - Add the ability to run multiple systemd instances with dedicated config files. (#16)
* Wed Mar 11 2020 UTC - shap-staff@suse.de
- Release 0.1.0
  [#]# Added
  - Implement the SAP Start Service collector (#6)
  - Implement the SAP Enqueue Server collector (#10)
  - Implement the SAP AS Dispatcher collector (#13)
  - Systemd unit (#8)
  - Metrics documentation (#10)
  - Design documentation (#10)
  [#]# Changed
  - Improved README and development notes (#7, a4dda15)
  [#]# Fixed
  - Better explain the `--sap-control-url` CLI flag (#14)
  - Typo in the example config (#12)
* Fri Feb 28 2020 UTC - shap-staff@suse.de
- Release 0.0.1
  [#]# Added
  - Copied boilerplate from [ClusterLabs/ha_cluster_exporter](//github.com/ClusterLabs/ha_cluster_exporter) (#2)
